@@ -1,6 +1,6 @@
 package Net::Google::Analytics;
 {
-  $Net::Google::Analytics::VERSION = '3.01';
+  $Net::Google::Analytics::VERSION = '3.02';
 }
 use strict;
 
@@ -170,7 +170,7 @@ sub retrieve_paged {
 
 1;
 
-
+__END__
 
 =pod
 
@@ -180,7 +180,7 @@ Net::Google::Analytics - Simple interface to the Google Analytics Core Reporting
 
 =head1 VERSION
 
-version 3.01
+version 3.02
 
 =head1 SYNOPSIS
 
@@ -225,7 +225,7 @@ version 3.01
     # Print results
 
     print
-        "Results: 1 - ", $res->items_per_page,
+        "Results: 1 - ", $res->num_rows,
         " of ", $res->total_results, "\n\n";
 
     for my $row (@{ $res->rows }) {
@@ -360,14 +360,9 @@ Nick Wellnhofer <wellnhofer@aevum.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Nick Wellnhofer.
+This software is copyright (c) 2014 by Nick Wellnhofer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
-
